@@ -1,16 +1,13 @@
 use criterion::{criterion_group, criterion_main, Criterion};
 
-use sshcerts::yubikey::{
-    RetiredSlotId,
-    SlotId,
-    Yubikey,
-};
+use sshcerts::yubikey::{RetiredSlotId, SlotId, Yubikey};
 
 fn generate_certs(n: u64) -> () {
     let data = [0; 32];
     let mut yk = Yubikey::new().unwrap();
     for _ in 0..n {
-        yk.ssh_cert_signer(&data, &SlotId::Retired(RetiredSlotId::R19)).unwrap();
+        yk.ssh_cert_signer(&data, &SlotId::Retired(RetiredSlotId::R19))
+            .unwrap();
     }
 }
 
@@ -19,4 +16,4 @@ pub fn criterion_benchmark(c: &mut Criterion) {
 }
 
 criterion_group!(benches, criterion_benchmark);
-criterion_main!(benches);
\ No newline at end of file
+criterion_main!(benches);
