@@ -6,10 +6,7 @@ pub mod generate;
 /// For parsing FIDO related data
 pub mod parsing;
 #[cfg(any(feature = "fido-support", feature = "fido-lite"))]
-pub use parsing::{
-    CoseKey,
-    AuthData,
-};
+pub use parsing::{AuthData, CoseKey};
 
 #[cfg(feature = "fido-support")]
 /// For signing related code
@@ -21,4 +18,4 @@ pub mod signing;
 pub mod verification;
 
 #[cfg(feature = "fido-support")]
-pub use generate::FIDOSSHKey;
\ No newline at end of file
+pub use generate::FIDOSSHKey;
