@@ -15,13 +15,13 @@ pub fn asn_der_to_r_s(buf: &[u8]) -> Option<(&[u8], &[u8])> {
     let r = &buf[..r_length];
     let buf = &buf[r_length..];
     if buf[0] != 0x2 {
-        return None
+        return None;
     }
     let s_length = buf[1] as usize;
     let s = &buf[2..];
 
     if s.len() != s_length {
-        return None
+        return None;
     }
 
     Some((r, s))
@@ -31,8 +31,8 @@ pub fn asn_der_to_r_s(buf: &[u8]) -> Option<(&[u8], &[u8])> {
 /// This function will take an ASN1 encoded ECDSA signature and return
 /// an SSH Signature blob
 pub fn signature_convert_asn1_ecdsa_to_ssh(signature: &[u8]) -> Option<Vec<u8>> {
-    let (r,s) = match asn_der_to_r_s(signature) {
-        Some((r,s)) => (r, s),
+    let (r, s) = match asn_der_to_r_s(signature) {
+        Some((r, s)) => (r, s),
         None => return None,
     };
     let mut sig_encoding: Vec<u8> = Vec::new();
@@ -57,16 +57,16 @@ pub fn format_signature_for_ssh(public_key: &PublicKey, signature: &[u8]) -> Opt
             } else {
                 return None;
             }
-        },
+        }
         PublicKeyKind::Rsa(_) => {
             writer.write_string("rsa-sha2-512");
             writer.write_bytes(signature);
-        },
+        }
         PublicKeyKind::Ed25519(_) => {
             writer.write_string(public_key.key_type.name);
             writer.write_bytes(signature);
         }
     };
-    
+
     Some(writer.into_bytes())
-}
\ No newline at end of file
+}
