@@ -1,18 +1,11 @@
 use x509_parser::prelude::FromDer;
 
 use crate::error::Error;
-use crate::ssh::{
-    Curve,
-    EcdsaPublicKey,
-    KeyType,
-    PublicKey,
-    PublicKeyKind,
-};
+use crate::ssh::{Curve, EcdsaPublicKey, KeyType, PublicKey, PublicKeyKind};
 
 use der_parser::der::parse_der_sequence;
 use der_parser::error::BerError;
 
-
 const OID_RSA_ENCRYPTION: &str = "1.2.840.113549.1.1.1";
 const OID_EC_PUBLIC_KEY: &str = "1.2.840.10045.2.1";
 const OID_NIST_P256: &str = "1.2.840.10045.3.1.7";
@@ -30,7 +23,6 @@ impl From<BerError> for Error {
     }
 }
 
-
 /// Helper function to convert a DER encoded public key, into an SSH formatted
 /// public key that can be used with the rest of the SSHCerts library. This
 /// function only supports NISTP256 and NISTP384 Ecdsa keys
@@ -39,18 +31,18 @@ pub fn der_encoding_to_ssh_public_key(key: &[u8]) -> Result<PublicKey, Error> {
     let parsed = parsed.as_sequence().map_err(|_| Error::ParsingError)?;
 
     if parsed.len() != 2 {
-        return Err(Error::ParsingError)
+        return Err(Error::ParsingError);
     }
 
     let oids = &parsed[0].as_sequence()?;
     if oids.len() != 2 {
-        return Err(Error::ParsingError)
+        return Err(Error::ParsingError);
     }
 
     let type_oid = oids[0].as_oid()?;
     let key_size_oid = oids[1].as_oid()?;
     if type_oid.to_id_string() != OID_EC_PUBLIC_KEY {
-        return Err(Error::ParsingError)
+        return Err(Error::ParsingError);
     }
 
     let data = &parsed[1].as_bitstring()?.data;
@@ -59,12 +51,12 @@ pub fn der_encoding_to_ssh_public_key(key: &[u8]) -> Result<PublicKey, Error> {
             let key_type = KeyType::from_name("ecdsa-sha2-nistp256").unwrap();
             let curve = Curve::from_identifier("nistp256").unwrap();
             (key_type, curve)
-        },
+        }
         OID_NIST_P384 => {
             let key_type = KeyType::from_name("ecdsa-sha2-nistp384").unwrap();
             let curve = Curve::from_identifier("nistp384").unwrap();
             (key_type, curve)
-        },
+        }
         _ => return Err(Error::KeyTypeMismatch),
     };
 
@@ -73,7 +65,7 @@ pub fn der_encoding_to_ssh_public_key(key: &[u8]) -> Result<PublicKey, Error> {
         key: data.to_vec(),
         sk_application: None,
     };
-    
+
     Ok(PublicKey {
         key_type,
         kind: PublicKeyKind::Ecdsa(kind),
@@ -86,7 +78,7 @@ pub fn der_encoding_to_ssh_public_key(key: &[u8]) -> Result<PublicKey, Error> {
 pub fn extract_ssh_pubkey_from_x509_certificate(cert: &[u8]) -> Result<PublicKey, Error> {
     let parsed_cert = match x509_parser::parse_x509_certificate(cert) {
         Ok((_, c)) => c,
-        Err(_) => return Err(Error::ParsingError)
+        Err(_) => return Err(Error::ParsingError),
     };
     let pki = &parsed_cert.tbs_certificate.subject_pki;
     convert_x509_pki_to_pubkey(pki)
@@ -95,19 +87,20 @@ pub fn extract_ssh_pubkey_from_x509_certificate(cert: &[u8]) -> Result<PublicKey
 /// This function is used to extract an SSH public key from an x509
 /// certificate signing request
 pub fn extract_ssh_pubkey_from_x509_csr(csr: &[u8]) -> Result<PublicKey, Error> {
-    let parsed_csr = match x509_parser::certification_request::X509CertificationRequest::from_der(csr) {
-        Ok((_, csr)) => csr,
-        Err(_) => return Err(Error::ParsingError)
-    };
+    let parsed_csr =
+        match x509_parser::certification_request::X509CertificationRequest::from_der(csr) {
+            Ok((_, csr)) => csr,
+            Err(_) => return Err(Error::ParsingError),
+        };
     let pki = &parsed_csr.certification_request_info.subject_pki;
     convert_x509_pki_to_pubkey(pki)
 }
 
-fn convert_x509_pki_to_pubkey(pki: &x509_parser::x509::SubjectPublicKeyInfo<'_>) -> Result<PublicKey, Error> {
+fn convert_x509_pki_to_pubkey(
+    pki: &x509_parser::x509::SubjectPublicKeyInfo<'_>,
+) -> Result<PublicKey, Error> {
     return match pki.algorithm.algorithm.to_string().as_str() {
-        OID_RSA_ENCRYPTION => {
-            Err(Error::Unsupported)
-        },
+        OID_RSA_ENCRYPTION => Err(Error::Unsupported),
         OID_EC_PUBLIC_KEY => {
             let key_bytes = &pki.subject_public_key.data;
             let algorithm_parameters = pki
@@ -116,7 +109,9 @@ fn convert_x509_pki_to_pubkey(pki: &x509_parser::x509::SubjectPublicKeyInfo<'_>)
                 .as_ref()
                 .ok_or(Error::ParsingError)?;
 
-            let curve_oid = algorithm_parameters.as_oid_val().map_err(|_| Error::ParsingError)?;
+            let curve_oid = algorithm_parameters
+                .as_oid_val()
+                .map_err(|_| Error::ParsingError)?;
 
             match curve_oid.to_string().as_str() {
                 OID_NIST_P256 => {
@@ -127,13 +122,13 @@ fn convert_x509_pki_to_pubkey(pki: &x509_parser::x509::SubjectPublicKeyInfo<'_>)
                         key: key_bytes.to_vec(),
                         sk_application: None,
                     };
-        
+
                     Ok(PublicKey {
                         key_type,
                         kind: PublicKeyKind::Ecdsa(kind),
                         comment: None,
                     })
-                },
+                }
                 OID_NIST_P384 => {
                     let key_type = KeyType::from_name("ecdsa-sha2-nistp384").unwrap();
                     let curve = Curve::from_identifier("nistp384").unwrap();
@@ -142,7 +137,7 @@ fn convert_x509_pki_to_pubkey(pki: &x509_parser::x509::SubjectPublicKeyInfo<'_>)
                         key: key_bytes.to_vec(),
                         sk_application: None,
                     };
-        
+
                     Ok(PublicKey {
                         key_type,
                         kind: PublicKeyKind::Ecdsa(kind),
@@ -153,5 +148,5 @@ fn convert_x509_pki_to_pubkey(pki: &x509_parser::x509::SubjectPublicKeyInfo<'_>)
             }
         }
         _ => Err(Error::ParsingError),
-    }
-}
\ No newline at end of file
+    };
+}
