@@ -1,10 +1,10 @@
+/// Contains all the functions used for creating new keys, unlocking, and
+/// managing the yubikey
+pub mod management;
 /// The SSH submodule contains functions relevant to SSH uses that are backed
 /// by the Yubikey. This includes things like signing and SSH public key
 /// export.
 pub mod ssh;
-/// Contains all the functions used for creating new keys, unlocking, and
-/// managing the yubikey
-pub mod management;
 
 /// Errors when interacting with the Yubikey.
 #[derive(Debug)]
@@ -43,7 +43,9 @@ pub use yubikey::{PinPolicy, TouchPolicy};
 
 /// Structure to wrap a yubikey and abstract actions
 pub struct Yubikey {
-    yk: yubikey::YubiKey,
+    /// We make this public to allow deeper access the Yubikey
+    /// type if needed
+    pub yk: yubikey::YubiKey,
 }
 
 impl std::fmt::Debug for Yubikey {
@@ -62,9 +64,16 @@ impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match *self {
             Error::Unprovisioned => write!(f, "Slot is unprovisioned for signing"),
-            Error::WrongKeyType => write!(f, "Wrong key type was provided for requested signing operation"),
-            Error::Unsupported => write!(f, "This key is not supported the way you tried to use it"),
-            Error::InvalidManagementKey => write!(f, "Could not use the management key as provided"),
+            Error::WrongKeyType => write!(
+                f,
+                "Wrong key type was provided for requested signing operation"
+            ),
+            Error::Unsupported => {
+                write!(f, "This key is not supported the way you tried to use it")
+            }
+            Error::InvalidManagementKey => {
+                write!(f, "Could not use the management key as provided")
+            }
             Error::ParsingError => write!(f, "Could not parse data"),
             Error::NoSuchYubikey => write!(f, "Could not find the requested Yubikey"),
             Error::InternalYubiKeyError(ref err) => write!(f, "Yubikey error: {}", err),
