@@ -1,4 +1,4 @@
-use sshcerts::ssh::{PublicKey};
+use sshcerts::ssh::PublicKey;
 
 #[test]
 fn parse_sk_ed25519() {
@@ -6,7 +6,10 @@ fn parse_sk_ed25519() {
     assert!(ssh_pubkey.is_ok());
     let ssh_pubkey = ssh_pubkey.unwrap();
 
-    assert_eq!(ssh_pubkey.fingerprint().hash, "GlvFAEnledYF0XG1guJ7dT2d0Mk88GmPAiHk8+zCBlA");
+    assert_eq!(
+        ssh_pubkey.fingerprint().hash,
+        "GlvFAEnledYF0XG1guJ7dT2d0Mk88GmPAiHk8+zCBlA"
+    );
 }
 
 #[test]
@@ -15,9 +18,12 @@ fn parse_sk_ecdsa256() {
     let ssh_pubkey = PublicKey::from_string(in_data);
     assert!(ssh_pubkey.is_ok());
     let ssh_pubkey = ssh_pubkey.unwrap();
-    
-    assert_eq!(ssh_pubkey.fingerprint().hash, "Ylfgx0U2M9/IVN0+b5/IxdNeVCotsdrRZ5lu5FG2ouc");
+
+    assert_eq!(
+        ssh_pubkey.fingerprint().hash,
+        "Ylfgx0U2M9/IVN0+b5/IxdNeVCotsdrRZ5lu5FG2ouc"
+    );
 
     let out_data = format!("{}", ssh_pubkey);
     assert_eq!(in_data, out_data);
-}
\ No newline at end of file
+}
